@@ -39,7 +39,9 @@
 
 #include <stdarg.h>
 
-#define X264_BUILD 110
+#include "x264_config.h"
+
+#define X264_BUILD 112
 
 /* x264_t:
  *      opaque handler for encoder */
@@ -388,6 +390,9 @@ typedef struct x264_param_t
         unsigned int i_bottom;
     } crop_rect;
 
+    /* frame packing arrangement flag */
+    int i_frame_packing;
+
     /* Muxing parameters */
     int b_aud;                  /* generate access unit delimiters */
     int b_repeat_headers;       /* put SPS/PPS before each keyframe */
@@ -670,7 +675,7 @@ typedef struct
     int     i_type;
     /* In: force quantizer for != X264_QP_AUTO */
     int     i_qpplus1;
-    /* In: pic_struct, for pulldown/doubling/etc...used only if b_pic_timing_sei=1.
+    /* In: pic_struct, for pulldown/doubling/etc...used only if b_pic_struct=1.
      *     use pic_struct_e for pic_struct inputs */
     int     i_pic_struct;
     /* Out: whether this frame is a keyframe.  Important when using modes that result in
